@@ -9,7 +9,7 @@
                      Header file for FK-editor
 */
 
-#define VERSION "1.5.26a"
+#define VERSION "1.5.29a"
 
 #include "Xwpe.h"
 #include "WeString.h"
@@ -237,13 +237,14 @@ typedef struct FNST {
 } FENSTER;
 
 typedef struct CNT {
- char dtmd, autosv; 
+ int major, minor, patch; /* Version of option file. */
  int maxcol, tabn;
  int maxchg, numundo;
  int flopt, edopt;
  int mxedt;           /* max number of exiting windows */
  int curedt;          /* currently active window */
  int edt[MAXEDT + 1]; /* 1 <= window IDs <= MAXEDT, arbitrary order */
+ int autoindent;
  char *print_cmd;
  char *dirct;         /* current directory */
  char *optfile, *tabs; 
@@ -251,7 +252,7 @@ typedef struct CNT {
  FIND fd;
  FARBE *fb;
  FENSTER *f[MAXEDT + 1];
- int autoindent;
+ char dtmd, autosv; 
 } ECNT;
 
 
@@ -345,6 +346,7 @@ typedef struct wpeOptionSection {
 extern struct CNT *WpeEditor;
 
 void e_ini_desk(ECNT *cn);
+void FARBE_Init(FARBE *fb);
 FARBE *e_ini_farbe();
 int e_switch_blst(ECNT *cn);
 void e_free_find(FIND *fd);
@@ -590,6 +592,8 @@ int e_rahmen_mouse(FENSTER *f);
 #endif
 
 /*   we_opt.c   */
+char *WpeStringToValue(const char *str);
+char *WpeValueToString(const char *value);
 int e_about_WE(FENSTER *f);
 int e_clear_desk(FENSTER *f);
 int e_repaint_desk(FENSTER *f);
@@ -741,6 +745,7 @@ int e_e_line_read(int n, signed char *s, int max);
 int e_d_dum_read(void);
 int e_d_p_exec(FENSTER *f);
 int e_d_getchar(void);
+int e_d_quit_basic(FENSTER *f);
 int e_d_quit(FENSTER *f);
 int e_d_add_watch(char *str, FENSTER *f);
 int e_remove_all_watches(FENSTER *f);
