@@ -429,11 +429,12 @@ int e_d_is_watch(int c, FENSTER *f)
   return(0);
 }
 
-int e_d_quit(FENSTER *f)
+int e_d_quit_basic(FENSTER *f)
 {
- ECNT *cn = f->ed;
  int i, kbdflgs;
 
+ if (!e_d_swtch)
+  return 0;
  if (rfildes[1] >= 0)
  {
   if (e_deb_type == 0 || e_deb_type == 3)
@@ -490,6 +491,13 @@ int e_d_quit(FENSTER *f)
    e_d_switch_out(0);
   }
  }
+}
+
+int e_d_quit(FENSTER *f)
+{
+ ECNT *cn = f->ed;
+ int i;
+ e_d_quit_basic(f);
  e_d_p_message(e_d_msg[ERR_ENDDEBUG], f, 1);
  WpeMouseChangeShape(WpeEditingShape);
  e_d_delbreak(f);
