@@ -706,120 +706,128 @@ int e_tst_cur(int c, ECNT *e)
 /*   function key (F1-F12) evaluation, editor only */
 int e_tst_fkt(int c, ECNT *e)
 {
-   extern OPT opt[];
-   int i;
-   FENSTER *f = e->f[e->mxedt];
+ extern OPT opt[];
+ int i;
+ FENSTER *f = e->f[e->mxedt];
+
 #ifdef PROG
-   if(e_tst_dfkt(f, c) == 0 ||
-		((WpeIsProg()) && e_prog_switch(f, c) == 0))
+ if (e_tst_dfkt(f, c) == 0 || ((WpeIsProg()) && e_prog_switch(f, c) == 0))
 #else
-   if(e_tst_dfkt(f, c) == 0)
+ if (e_tst_dfkt(f, c) == 0)
 #endif
-   {
-      f = e->f[e->mxedt];
-      fk_cursor(1);
-      if(e->mxedt > 0) e_cursor(f, 1);
-      return(0);
-   }
-   
-   for(i = 0; i < MENOPT; i++)
-   if(c == opt[i].as) WpeHandleMainmenu(i, f);
-   
-   switch (c)
-   {  case CtrlK:
-	 e_ctrl_k(f);    /*  ctrl k  */
-	 break;
-      case CtrlO:      /*  ctrl o  */
-	 e_ctrl_o(f);
-	 break;
-      case AltG:
-	 e_goto_line(f);
-	 break;
-      case CF10:
-      case CtrlW:
-	 e_show_clipboard(f);
-	 break;
-      case CtrlDel:
-	 e_blck_del(f);
-	 break;
-      case UNDO:
-      case AltBS:
-      case CtrlU:
-	 e_make_undo(f);
-	 break;
-      case AGAIN:
-      case SABS:
-      case CtrlR:
-	 e_make_redo(f);
-	 break;
-      case CUT:
-      case ShiftDel:    /*  shift Del  :  Delete to Clipboard  */
+ {
+  f = e->f[e->mxedt];
+  fk_cursor(1);
+  if (e->mxedt > 0)
+   e_cursor(f, 1);
+  return(0);
+ }
+
+ for (i = 0; i < MENOPT; i++)
+  if (c == opt[i].as)
+   WpeHandleMainmenu(i, f);
+
+ switch (c)
+ {
+  case CtrlK:
+   e_ctrl_k(f);    /*  ctrl k  */
+   break;
+  case CtrlO:      /*  ctrl o  */
+   e_ctrl_o(f);
+   break;
+  case AltG:
+   e_goto_line(f);
+   break;
+  case CF10:
+  case CtrlW:
+   e_show_clipboard(f);
+   break;
+  case CtrlDel:
+   e_blck_del(f);
+   break;
+  case UNDO:
+  case AltBS:
+  case CtrlU:
+   e_make_undo(f);
+   break;
+  case AGAIN:
+  case SABS:
+  case CtrlR:
+   e_make_redo(f);
+   break;
+  case CUT:
+  case ShiftDel:    /*  shift Del  :  Delete to Clipboard  */
 /*               case 402:     */
-      case CtrlX:
-	 e_edt_del(f);
-	 break;
-      case PASTE:
-      case ShiftEin:    /*  shift Einf  */
-      case CtrlV:
-	 e_edt_einf(f);
-	 break;
+  case CtrlX:
+   e_edt_del(f);
+   break;
+  case PASTE:
+  case ShiftEin:    /*  shift Einf  */
+  case CtrlV:
+   e_edt_einf(f);
+   break;
 #if !defined(NO_XWINDOWS)
-      case AltEin:
-	 e_copy_X_buffer(f);
-	 break;
-      case AltDel:
-	 e_paste_X_buffer(f);
-	 break;
+  case AltEin:
+   e_copy_X_buffer(f);
+   break;
+  case AltDel:
+   e_paste_X_buffer(f);
+   break;
 #endif
-      case COPY:
-      case CtrlEin:    /*  ctrl Einf  */
+  case COPY:
+  case CtrlEin:    /*  ctrl Einf  */
 /*               case 401:    */
-      case CtrlC:
-	 e_edt_copy(f);
-	 break;
-      default:
-	 if(f->ed->edopt & ED_CUA_STYLE)
-	 {  switch(c)
-	    {  case AF2:
-		  e_m_save(f);
-		  break;
-	       case FID:
-	       case AF3:
-		  e_find(f);
-		  break;
-	       case SF3:
-		  e_replace(f);
-		  break;
-	       case F3:
-		  e_rep_search(f);
-		  break;
-	       default:
-		  return(c);
-	    }
-	 }
-	 else
-	 {  switch(c)
-	    {  case F2:
-		  e_m_save(f);
-		  break;
-	       case FID:
-	       case F4:
-		  e_find(f);
-		  break;
-	       case AF4:
-		  e_replace(f);
-		  break;
-	       case CtrlL:
-	       case CF4:
-		  e_rep_search(f);
-		  break;
-	       default:
-		  return(c);
-	    }
-	 }
+  case CtrlC:
+   e_edt_copy(f);
+   break;
+  default:
+   if (f->ed->edopt & ED_CUA_STYLE)
+   {
+    switch (c)
+    {
+     case AF2:
+      e_m_save(f);
+      break;
+     case FID:
+     case AF3:
+      e_find(f);
+      break;
+     case SF3:
+      e_replace(f);
+      break;
+     case F3:
+      e_rep_search(f);
+      break;
+     default:
+      return(c);
+    }
    }
-   fk_cursor(1);
-   return(0);
+   else
+   {
+    switch(c)
+    {
+     case F2:
+      e_m_save(f);
+      break;
+     case FID:
+     case F4:
+      e_find(f);
+      break;
+     case AF4:
+      e_replace(f);
+      break;
+     case CtrlL:
+     case CF4:
+      e_rep_search(f);
+      break;
+     default:
+      return(c);
+    }
+   }
+   break;
+ }
+ fk_cursor(1);
+ return(0);
 }
 
 int e_ctrl_k(FENSTER *f)
@@ -922,113 +930,123 @@ int e_ctrl_k(FENSTER *f)
 /*   Ctrl - O - Dispatcher     */
 int e_ctrl_o(FENSTER *f)
 {
-   BUFFER *b = f->ed->f[f->ed->mxedt]->b;
-   SCHIRM *s = f->ed->f[f->ed->mxedt]->s;
-   int i, c;
-   unsigned char cc;
-   c = e_toupper(e_getch());
-   if( c < 32 ) c = c + 'A' - 1;
-   switch(c)
-   {  case 'Y':     /*  delete end of line    */
-	 if(f->ins == 8) break;
-	 e_del_nchar(b, s, b->b.x, b->b.y, b->bf[b->b.y].len-b->b.x);
-	 e_schirm(f, 1);
-	 e_cursor(f, 1);
-	 break;
-      case 'T':     /*  delete up to beginning of next word    */
-	 if(f->ins == 8) break;
-	 if(b->b.x <= 0 && b->b.y > 0)
-	 {  b->b.y--;
-	    b->b.x = b->bf[b->b.y].len;
-	 }
-	 else if( b->b.x > 0 )
-	 {  c = b->b.x;
-	    b->b.x = e_su_rblk(b->b.x - 1, b->bf[b->b.y].s);
-	    e_del_nchar(b, s, b->b.x, b->b.y, c-b->b.x);
-	 }
-	 e_schirm(f, 1);
-	 break;
-      case 'F':     /*  find string    */
-	 e_find(f);
-	 break;
-      case 'A':     /*  replace string    */
-	 e_replace(f);
-	 break;
-#ifdef PROG
-      case 'S':     /*  find declaration    */
-	 e_sh_def(f);
-	 break;
-      case 'N':     /*  ...next...  */
-	 e_sh_nxt_def(f);
-	 break;
-      case 'K':     /*  next bracket  */
-	 e_nxt_brk(f);
-	 break;
-      case 'B':     /*  beautify text  */
-	 e_p_beautify(f);
-	 break;
-#endif
-      case 'U':     /*   for help file: create button */
-	 if(s->mark_begin.y == s->mark_end.y && s->mark_begin.y >= 0 && s->mark_begin.x < s->mark_end.x)
-	 {  cc = HED;
-	    e_ins_nchar(b, s, &cc, s->mark_end.x, s->mark_end.y, 1);
-	    cc = HBG;
-	    e_ins_nchar(b, s, &cc, s->mark_begin.x, s->mark_end.y, 1);
-	    e_schirm(f, 1);
-	 }
-	 break;
-      case 'M':     /*   for help file: Mark-Line  */
-	 if(s->mark_begin.y == s->mark_end.y && s->mark_begin.y >= 0 && s->mark_begin.x < s->mark_end.x)
-	 {  cc = HED;
-	    e_ins_nchar(b, s, &cc, s->mark_end.x, s->mark_end.y, 1);
-	    cc = HBB;
-	    e_ins_nchar(b, s, &cc, s->mark_begin.x, s->mark_end.y, 1);
-	    e_schirm(f, 1);
-	 }
-	 break;
-      case 'H':     /*   for help file: create Header  */
-	 if(s->mark_begin.y == s->mark_end.y && s->mark_begin.y >= 0 && s->mark_begin.x < s->mark_end.x)
-	 {  cc = HED;
-	    e_ins_nchar(b, s, &cc, s->mark_end.x, s->mark_end.y, 1);
-	    cc = HHD;
-	    e_ins_nchar(b, s, &cc, s->mark_begin.x, s->mark_end.y, 1);
-	    e_schirm(f, 1);
-	 }
-	 break;
-      case 'E':     /*   for help file: create end mark  */
-	 e_new_line(b->b.y, b);
-	 cc = HFE;
-	 e_ins_nchar(b, s, &cc, 0, b->b.y, 1);
-	 e_schirm(f, 1);
-	 break;
-      case 'L':     /*   for help file: delete "help" special chars  */
-	 for(i = 0; i < b->bf[b->b.y].len; i++)
-	 if(b->bf[b->b.y].s[i] == HBG || b->bf[b->b.y].s[i] == HED
-		   || b->bf[b->b.y].s[i] == HHD || b->bf[b->b.y].s[i] == HBB
-		   || b->bf[b->b.y].s[i] == HFE || b->bf[b->b.y].s[i] == HFB
-		   || b->bf[b->b.y].s[i] == HFE)
-	 {  e_del_nchar(b, s, i, b->b.y, 1);  i--;  }
-	 e_schirm(f, 1);
-	 break;
-      case 'C':     /*   for help file: check help file   */
-	 e_help_comp(f);
-	 break;
-      case '0':
-      case '1':
-      case '2':
-      case '3':
-      case '4':
-      case '5':
-      case '6':
-      case '7':
-      case '8':
-      case '9':
-	 b->b.x = s->pt[c-'0'].x;  b->b.y = s->pt[c-'0'].y;
-	 s->fa.y = b->b.y;  s->fa.x = b->b.x;  s->fe.x = b->b.x+1;
-	 e_cursor(f, 1);
-	 break;
+ BUFFER *b = f->ed->f[f->ed->mxedt]->b;
+ SCHIRM *s = f->ed->f[f->ed->mxedt]->s;
+ int i, c;
+ unsigned char cc;
+
+ c = e_toupper(e_getch());
+ if (c < 32) c = c + 'A' - 1;
+ switch(c)
+ {
+  case 'Y':     /*  delete end of line    */
+   if (f->ins == 8) break;
+   e_del_nchar(b, s, b->b.x, b->b.y, b->bf[b->b.y].len-b->b.x);
+   e_schirm(f, 1);
+   e_cursor(f, 1);
+   break;
+  case 'T':     /*  delete up to beginning of next word    */
+   if (f->ins == 8) break;
+   if (b->b.x <= 0 && b->b.y > 0)
+   {
+    b->b.y--;
+    b->b.x = b->bf[b->b.y].len;
    }
-   return(0);
+   else if (b->b.x > 0)
+   {
+    c = b->b.x;
+    b->b.x = e_su_rblk(b->b.x - 1, b->bf[b->b.y].s);
+    e_del_nchar(b, s, b->b.x, b->b.y, c-b->b.x);
+   }
+   e_schirm(f, 1);
+   break;
+  case 'F':     /*  find string    */
+   e_find(f);
+   break;
+  case 'A':     /*  replace string    */
+   e_replace(f);
+   break;
+#ifdef PROG
+  case 'S':     /*  find declaration    */
+   e_sh_def(f);
+   break;
+  case 'N':     /*  ...next...  */
+   e_sh_nxt_def(f);
+   break;
+  case 'K':     /*  next bracket  */
+   e_nxt_brk(f);
+   break;
+  case 'B':     /*  beautify text  */
+   e_p_beautify(f);
+   break;
+#endif
+  case 'U':     /*   for help file: create button */
+   if (s->mark_begin.y == s->mark_end.y && s->mark_begin.y >= 0 && s->mark_begin.x < s->mark_end.x)
+   {
+    cc = HED;
+    e_ins_nchar(b, s, &cc, s->mark_end.x, s->mark_end.y, 1);
+    cc = HBG;
+    e_ins_nchar(b, s, &cc, s->mark_begin.x, s->mark_end.y, 1);
+    e_schirm(f, 1);
+   }
+   break;
+  case 'M':     /*   for help file: Mark-Line  */
+   if (s->mark_begin.y == s->mark_end.y && s->mark_begin.y >= 0 && s->mark_begin.x < s->mark_end.x)
+   {
+    cc = HED;
+    e_ins_nchar(b, s, &cc, s->mark_end.x, s->mark_end.y, 1);
+    cc = HBB;
+    e_ins_nchar(b, s, &cc, s->mark_begin.x, s->mark_end.y, 1);
+    e_schirm(f, 1);
+   }
+   break;
+  case 'H':     /*   for help file: create Header  */
+   if (s->mark_begin.y == s->mark_end.y && s->mark_begin.y >= 0 && s->mark_begin.x < s->mark_end.x)
+   {
+    cc = HED;
+    e_ins_nchar(b, s, &cc, s->mark_end.x, s->mark_end.y, 1);
+    cc = HHD;
+    e_ins_nchar(b, s, &cc, s->mark_begin.x, s->mark_end.y, 1);
+    e_schirm(f, 1);
+   }
+   break;
+  case 'E':     /*   for help file: create end mark  */
+   e_new_line(b->b.y, b);
+   cc = HFE;
+   e_ins_nchar(b, s, &cc, 0, b->b.y, 1);
+   e_schirm(f, 1);
+   break;
+  case 'L':     /*   for help file: delete "help" special chars  */
+   for (i = 0; i < b->bf[b->b.y].len; i++)
+    if (b->bf[b->b.y].s[i] == HBG || b->bf[b->b.y].s[i] == HED ||
+      b->bf[b->b.y].s[i] == HHD || b->bf[b->b.y].s[i] == HBB ||
+      b->bf[b->b.y].s[i] == HFE || b->bf[b->b.y].s[i] == HFB ||
+      b->bf[b->b.y].s[i] == HFE)
+    {
+     e_del_nchar(b, s, i, b->b.y, 1);
+     i--;
+    }
+   e_schirm(f, 1);
+   break;
+  case 'C':     /*   for help file: check help file   */
+   e_help_comp(f);
+   break;
+  case '0':
+  case '1':
+  case '2':
+  case '3':
+  case '4':
+  case '5':
+  case '6':
+  case '7':
+  case '8':
+  case '9':
+   b->b.x = s->pt[c-'0'].x;  b->b.y = s->pt[c-'0'].y;
+   s->fa.y = b->b.y;  s->fa.x = b->b.x;  s->fe.x = b->b.x+1;
+   e_cursor(f, 1);
+   break;
+ }
+ return(0);
 }
 
 /* general function key dispatcher 
