@@ -7,16 +7,6 @@
 #include "edit.h"
 #include <regex.h>
 
-/*   capitalize letters (German) */
-int e_toupper(int c)
-{
- if (c >= 'a' && c <= 'z')
-  c = c - 'a' + 'A';
- else if (c >= 0xe0 && c <= 0xfe)
-  c = c - 0x20;
- return (c);
-}
-
 /*        find string in text line    */
 int e_strstr(int x, int n, unsigned char *s, unsigned char *f)
 {
@@ -47,7 +37,7 @@ int e_strstr(int x, int n, unsigned char *s, unsigned char *f)
  return(-1);
 }
 
-/*        String in Zeile finden (ohne Gross- und Kleinschreibung)   */
+/*        Find string in line (ignoring case)   */
 int e_ustrstr(int x, int n, unsigned char *s, unsigned char *f)
 {
  int i, j, nf = strlen(f);
@@ -189,11 +179,12 @@ int e_str_len(unsigned char *s)
 {
  int i;
 
- for (i = 0; *(s+i) != '\0' && *(s+i) != WPE_WR && *(s+i) != WPE_CR; i++)
+ for (i = 0; *(s+i) != '\0' && *(s+i) != WPE_WR; i++)
   ;
  return (i);
 }
 
+#if 0
 /*   determine number of chars in a string */
 int e_str_nrc(unsigned char *s)
 {
@@ -204,7 +195,18 @@ int e_str_nrc(unsigned char *s)
  return (i);
 }
 
-/*	     COLOR - Struktur mit Konstanten belegen           */
+/*   capitalize letters (German) */
+int e_toupper(int c)
+{
+ if (c >= 'a' && c <= 'z')
+  c = c - 'a' + 'A';
+ else if (c >= 0xe0 && c <= 0xfe)
+  c = c - 0x20;
+ return (c);
+}
+#endif
+
+/*           COLOR - fill struct with constants           */
 COLOR e_s_x_clr(int f, int b)
 {
  COLOR c;
