@@ -386,75 +386,76 @@ int e_comp(FENSTER *f)
 
 int e_exec_inf(FENSTER *f, char **argv, int n)
 {
-   int pid;
-   char tstr[128];
+ int pid;
+ char tstr[128];
 #ifdef DEBUGGER
-   if (e_d_swtch > 0)
-    e_d_quit(f);
+ if (e_d_swtch > 0)
+  e_d_quit(f);
 #endif
-   fflush(stdout);
-   sprintf(tstr, "%s/we_111", e_tmp_dir);
-   if((efildes[1] = creat(tstr, 0777)) < 0)
-   {
-    e_error(e_p_msg[ERR_PIPEOPEN], 0, f->fb);
-    return(0);
-   }
-   if((efildes[0] = open(tstr, O_RDONLY)) < 0 )
-   {
-    e_error(e_p_msg[ERR_PIPEOPEN], 0, f->fb);
-    return(0);
-   }
-   efile = MALLOC((strlen(tstr)+1)*sizeof(char));
-   strcpy(efile, tstr);
-   sprintf(tstr, "%s/we_112", e_tmp_dir);
-   if((wfildes[1] = creat(tstr, 0777)) < 0)
-   {
-    e_error(e_p_msg[ERR_PIPEOPEN], 0, f->fb);
-    return(0);
-   }
-   if((wfildes[0] = open(tstr, O_RDONLY)) < 0 )
-   {
-    e_error(e_p_msg[ERR_PIPEOPEN], 0, f->fb);
-    return(0);
-   }
-   wfile = MALLOC((strlen(tstr)+1)*sizeof(char));
-   strcpy(wfile, tstr);
-   
-   if((e_save_pid = pid = fork()) > 0)
-    return(efildes[1]);
-   else if(pid < 0)
-   {
-    e_error(e_p_msg[ERR_PROCESS], 0, f->fb);
-    return(0);
-   }
-   
-   close(2);   /*  new process   */
-   if(fcntl(efildes[1], F_DUPFD, 2) != 2)
-   {
-    fprintf(stderr, e_p_msg[ERR_PIPEEXEC], efildes[1]);
-    exit(1);
-   }
-   close(1);
-   if(fcntl(wfildes[1], F_DUPFD, 1) != 1)
-   {
-    fprintf(stderr, e_p_msg[ERR_PIPEEXEC], wfildes[1]);
-    exit(1);
-   }
-   e_print_arg(stderr, "", argv, n);
-   execvp(argv[0], argv);
-   e_print_arg(stderr, e_p_msg[ERR_IN_COMMAND], argv, n);
-   exit(1);
-   /* Can never get here */
-   return 0;
+ fflush(stdout);
+ sprintf(tstr, "%s/we_111", e_tmp_dir);
+ if((efildes[1] = creat(tstr, 0777)) < 0)
+ {
+  e_error(e_p_msg[ERR_PIPEOPEN], 0, f->fb);
+  return(0);
+ }
+ if((efildes[0] = open(tstr, O_RDONLY)) < 0 )
+ {
+  e_error(e_p_msg[ERR_PIPEOPEN], 0, f->fb);
+  return(0);
+ }
+ efile = MALLOC((strlen(tstr)+1)*sizeof(char));
+ strcpy(efile, tstr);
+ sprintf(tstr, "%s/we_112", e_tmp_dir);
+ if((wfildes[1] = creat(tstr, 0777)) < 0)
+ {
+  e_error(e_p_msg[ERR_PIPEOPEN], 0, f->fb);
+  return(0);
+ }
+ if((wfildes[0] = open(tstr, O_RDONLY)) < 0 )
+ {
+  e_error(e_p_msg[ERR_PIPEOPEN], 0, f->fb);
+  return(0);
+ }
+ wfile = MALLOC((strlen(tstr)+1)*sizeof(char));
+ strcpy(wfile, tstr);
+
+ if((e_save_pid = pid = fork()) > 0)
+  return(efildes[1]);
+ else if(pid < 0)
+ {
+  e_error(e_p_msg[ERR_PROCESS], 0, f->fb);
+  return(0);
+ }
+
+ close(2);   /*  new process   */
+ if(fcntl(efildes[1], F_DUPFD, 2) != 2)
+ {
+  fprintf(stderr, e_p_msg[ERR_PIPEEXEC], efildes[1]);
+  exit(1);
+ }
+ close(1);
+ if(fcntl(wfildes[1], F_DUPFD, 1) != 1)
+ {
+  fprintf(stderr, e_p_msg[ERR_PIPEEXEC], wfildes[1]);
+  exit(1);
+ }
+ e_print_arg(stderr, "", argv, n);
+ execvp(argv[0], argv);
+ e_print_arg(stderr, e_p_msg[ERR_IN_COMMAND], argv, n);
+ exit(1);
+ /* Can never get here */
+ return 0;
 }
 
 int e_print_arg(FILE *fp, char *s, char **argv, int n)
 {
  int i;
 
- fprintf(fp,"%s", s);
+ if ((s) && (s[0]))
+  fprintf(fp,"%s ", s);
  for (i = 0; i < n && argv[i] != NULL; i++)
-  fprintf(fp," %s", argv[i]);
+  fprintf(fp,"%s ", argv[i]);
  fprintf(fp,"\n");
  return(n);
 }
@@ -531,75 +532,97 @@ int e_p_exec(int file, FENSTER *f, PIC *pic)
 /* show source-position of error number "n" from actual errorlist */
 int e_show_error(int n, FENSTER *f)
 {
-   ECNT *cn = f->ed;
-   BUFFER *b = cn->f[cn->mxedt]->b;
-   int i, j, bg = 0;
-   char *filename;
-   unsigned char *cp;
+ ECNT *cn = f->ed;
+ BUFFER *b = cn->f[cn->mxedt]->b;
+ int i, j, bg = 0;
+ char *filename;
+ unsigned char *cp;
 
-   if(!err_li || n >= err_num || n < 0)
-    return(1);
-   f = cn->f[cn->mxedt];
-   if(err_li[n].file[0] == '.' && err_li[n].file[1] == DIRC)
-    bg = 2;
-   if (err_li[n].file[0] == DIRC)
+ if (!err_li || n >= err_num || n < 0)
+  return(1);
+ f = cn->f[cn->mxedt];
+ if (err_li[n].file[0] == '.' && err_li[n].file[1] == DIRC)
+  bg = 2;
+ if (err_li[n].file[0] == DIRC)
+ {
+  filename = e_mkfilename(f->dirct, f->datnam);
+ }
+ else
+  filename = f->datnam;
+ if (strcmp(err_li[n].file+bg, filename))
+ {
+  for (i = cn->mxedt - 1; i > 0; i--)
+  {
+   if (filename != cn->f[i+1]->datnam)
    {
-    filename = e_mkfilename(f->dirct, f->datnam);
-   }
-   else filename = f->datnam;
-   if (strcmp(err_li[n].file+bg, filename))
-   {  for(i = cn->mxedt - 1; i > 0; i--)
-      {  if(filename != cn->f[i+1]->datnam)
-	 {  FREE(filename);
-	    filename = e_mkfilename(cn->f[i]->dirct, cn->f[i]->datnam);
-	 }
-	 else filename = cn->f[i]->datnam;
-	 if(!strcmp(err_li[n].file+bg, filename))
-	 {  if(filename != cn->f[i]->datnam) FREE(filename);
-            e_switch_window(cn->edt[i], cn->f[cn->mxedt]);
-            break;  
-         }
-      }
-      if(i <= 0)
-      {  if (filename != cn->f[i+1]->datnam) FREE(filename); 
-         if (e_edit(cn, err_li[n].file)) return(WPE_ESC);
-      }
-   }
-   else if(filename != f->datnam) FREE(filename);
-   e_pr_str_wsd(1, MAXSLNS - 1, err_li[n].text, f->fb->mt.fb, -1, 0,
-						f->fb->mt.fb, 1, MAXSCOL-2);
-/*   e_pr_nstr(2, MAXSLNS - 1, MAXSCOL-2, err_li[n].text,
-                                                f->fb->mt.fb, f->fb->mt.fb); */
-   b = cn->f[cn->mxedt]->b;
-   b->b.y = err_li[n].line > b->mxlines ? b->mxlines - 1 : err_li[n].line - 1;
-   if (!err_li[n].srch)
-   {  for(i = j = 0; i + j < err_li[n].x && i < b->bf[b->b.y].len; i++)
-      {  if(*(b->bf[b->b.y].s + i) == WPE_TAB)
-	 j += (f->ed->tabn - ((j + i) % f->ed->tabn) - 1);
-#ifdef UNIX
-	 else if(((unsigned char) *(b->bf[b->b.y].s + i)) > 126)
-	 {  j++;
-	    if(((unsigned char) *(b->bf[b->b.y].s + i)) < 128 + ' ') j++;
-	 }
-	 else if(*(b->bf[b->b.y].s + i) < ' ') j++;
-#endif
-      }
-      b->b.x = i;
+    FREE(filename);
+    filename = e_mkfilename(cn->f[i]->dirct, cn->f[i]->datnam);
    }
    else
-   {  cp = strstr(b->bf[b->b.y].s, err_li[n].srch+1);
-      for(i = 0; b->bf[b->b.y].s + i < cp; i++);
-      if(err_li[n].srch[0] == 'B')
-      {  for(i--; i >= 0 && isspace(b->bf[b->b.y].s[i]); i--);
-	 if(i < 0 && b->b.y > 0)
-	 {  (b->b.y)--;  i = b->bf[b->b.y].len+1;  }
-	 else i++;
-      }
-/*      else if(err_li[n].x < -1) i++;    */
-      b->b.x = i +  err_li[n].x;
+    filename = cn->f[i]->datnam;
+   if (!strcmp(err_li[n].file+bg, filename))
+   {
+    if (filename != cn->f[i]->datnam)
+     FREE(filename);
+    e_switch_window(cn->edt[i], cn->f[cn->mxedt]);
+    break;  
    }
-   e_cursor(cn->f[cn->mxedt],1);
-   return(0);
+  }
+  if (i <= 0)
+  {
+   if (filename != cn->f[i+1]->datnam)
+    FREE(filename); 
+   if (e_edit(cn, err_li[n].file))
+    return(WPE_ESC);
+  }
+ }
+ else if (filename != f->datnam)
+  FREE(filename);
+ e_pr_str_wsd(1, MAXSLNS - 1, err_li[n].text, f->fb->mt.fb, -1, 0,
+   f->fb->mt.fb, 1, MAXSCOL-2);
+/*   e_pr_nstr(2, MAXSLNS - 1, MAXSCOL-2, err_li[n].text,
+                                                f->fb->mt.fb, f->fb->mt.fb); */
+ b = cn->f[cn->mxedt]->b;
+ b->b.y = err_li[n].line > b->mxlines ? b->mxlines - 1 : err_li[n].line - 1;
+ if (!err_li[n].srch)
+ {
+  for(i = j = 0; i + j < err_li[n].x && i < b->bf[b->b.y].len; i++)
+  {
+   if (*(b->bf[b->b.y].s + i) == WPE_TAB)
+    j += (f->ed->tabn - ((j + i) % f->ed->tabn) - 1);
+#ifdef UNIX
+   else if (((unsigned char) *(b->bf[b->b.y].s + i)) > 126)
+   {
+    j++;
+    if (((unsigned char) *(b->bf[b->b.y].s + i)) < 128 + ' ')
+     j++;
+   }
+   else if (*(b->bf[b->b.y].s + i) < ' ')
+    j++;
+#endif
+  }
+  b->b.x = i;
+ }
+ else
+ {
+  cp = strstr(b->bf[b->b.y].s, err_li[n].srch+1);
+  for (i = 0; b->bf[b->b.y].s + i < cp; i++);
+  if (err_li[n].srch[0] == 'B')
+  {
+   for (i--; i >= 0 && isspace(b->bf[b->b.y].s[i]); i--);
+   if (i < 0 && b->b.y > 0)
+   {
+    (b->b.y)--;
+    i = b->bf[b->b.y].len+1;
+   }
+   else
+    i++;
+  }
+/*      else if(err_li[n].x < -1) i++;    */
+  b->b.x = i +  err_li[n].x;
+ }
+ e_cursor(cn->f[cn->mxedt],1);
+ return(0);
 }
 
 int e_pure_bin(char *str, int ch)
@@ -1064,6 +1087,7 @@ int e_project_options(FENSTER *f)
 {
  int ret;
  W_OPTSTR *o = e_init_opt_kst(f);
+ char *messagestring;
 
  if (!o)
   return(-1);
@@ -1082,7 +1106,9 @@ int e_project_options(FENSTER *f)
  e_add_wrstr(4, 6, 22, 6, 36, 256, 0, AltL, "Loader-Options:", e_s_prog.libraries, NULL, o);
  e_add_wrstr(4, 8, 22, 8, 36, 128, 0, AltE, "Executable:", e_s_prog.exe_name, NULL, o);
  e_add_wrstr(4, 10, 22, 10, 36, 128, 2, AltB, "LiBrary:", library, NULL, o);
- e_add_wrstr(22, 12, 22, 13, 36, 256, 0, AltM, "Message-String:", e_s_prog.intstr, NULL, o);
+ messagestring = WpeStringToValue(e_s_prog.intstr);
+ e_add_wrstr(22, 12, 22, 13, 36, 256, 0, AltM, "Message-String:", messagestring, NULL, o);
+ WpeFree(messagestring);
  e_add_pswstr(0, 5, 13, 0, AltG, 0, "GNU       ", o);
  e_add_pswstr(0, 5, 14, 1, AltT, e_s_prog.comp_sw, "OTher     ", o);
  e_add_bttstr(9, 18, 0, AltS, "Save", NULL, o);
@@ -1103,7 +1129,7 @@ int e_project_options(FENSTER *f)
   if (e_s_prog.exe_name) FREE(e_s_prog.exe_name);
   e_s_prog.exe_name = WpeStrdup(o->wstr[3]->txt);
   if (e_s_prog.intstr) FREE(e_s_prog.intstr);
-  e_s_prog.intstr = WpeStrdup(o->wstr[5]->txt);
+  e_s_prog.intstr = WpeValueToString(o->wstr[5]->txt);
   strcpy(library, o->wstr[4]->txt);
   e_s_prog.comp_sw = o->pstr[0]->num;
   e_wrt_prj_fl(f);
@@ -1120,6 +1146,7 @@ int e_run_c_options(FENSTER *f)
  W_OPTSTR *o = e_init_opt_kst(f);
  char filepostfix[128];
  char *newpostfix;
+ char *messagestring;
 
  if (!o)
   return(-1);
@@ -1144,7 +1171,9 @@ int e_run_c_options(FENSTER *f)
   }
  }
  e_add_wrstr(4, 12, 22, 12, 36, 128, 0, AltF, "File-Postfix:", filepostfix, NULL, o);
- e_add_wrstr(22, 14, 22, 15, 36, 128, 0, AltM, "Message-String:", e_s_prog.intstr , NULL, o);
+ messagestring = WpeStringToValue(e_s_prog.intstr);
+ e_add_wrstr(22, 14, 22, 15, 36, 128, 0, AltM, "Message-String:", messagestring, NULL, o);
+ WpeFree(messagestring);
  e_add_pswstr(0, 5, 15, 0, AltG, 0, "GNU      ", o);
  e_add_pswstr(0, 5, 16, 1, AltT, e_s_prog.comp_sw, "OTher    ", o);
  e_add_bttstr(16, 18, 1, AltO, " Ok ", NULL, o);
@@ -1179,7 +1208,7 @@ int e_run_c_options(FENSTER *f)
    i = j - 1;
   }
   if (e_s_prog.intstr) FREE(e_s_prog.intstr);
-  e_s_prog.intstr = WpeStrdup(o->wstr[6]->txt);
+  e_s_prog.intstr = WpeValueToString(o->wstr[6]->txt);
   e_s_prog.comp_sw = o->pstr[0]->num;
  }
  freeostr(o);
@@ -1446,9 +1475,7 @@ int e_system(char *estr, ECNT *cn)
  fk_cursor(1);
  (*e_u_s_sys_ini)();
  ret = system(estr);
-#ifndef DJGPP
  if (!WpeIsXwin())
-#endif
  {
   printf(e_msg[ERR_HITCR]);
   fflush(stdout);
@@ -1826,7 +1853,7 @@ int e_read_var(FENSTER *f)
   {  p_v = tmp;  fclose(fp);  e_error(e_msg[ERR_LOWMEM], 0, f->fb);  return(-1);  }
   if (!(p_v[p_v_n-1] = MALLOC(sizeof(struct proj_var))))
   {  fclose(fp);  e_error(e_msg[ERR_LOWMEM], 0, f->fb);  return(-1);  }
-  if (!(p_v[p_v_n-1]->var = MALLOC((i+1) * sizeof(char))))
+  if (!(p_v[p_v_n-1]->var = MALLOC((strlen(sp1)+1) * sizeof(char))))
   {  fclose(fp);  e_error(e_msg[ERR_LOWMEM], 0, f->fb);  return(-1);  }
   strcpy(p_v[p_v_n-1]->var, sp1);
   if (!(p_v[p_v_n-1]->string = MALLOC((strlen(sp2)+1) * sizeof(char))))
@@ -2865,199 +2892,283 @@ int e_p_konv_mess(char *var, char *str, char *txt, char *file, char *cmp,
 int e_p_comp_mess(char *a, char *b, char *c, char *txt, char *file, char *cmp,
   int *y, int *x)
 {
-   int i, n, k = 0, bsl = 0;
-   char *ctmp, *cp, *var = NULL, *str = NULL;
+ int i, n, k = 0, bsl = 0;
+ char *ctmp, *cp, *var = NULL, *str = NULL;
 
-   if(c > b) return(0);
-   if(a[0] == '*' && !a[1]) return(2);
-   if(!a[0] && !b[0]) return(2);
-   if(!a[0] || !b[0]) return(0);
-   if(a[0] == '*' && (a[1] == '*' || a[1] == '$'))
-	return(e_p_comp_mess(++a, b, c, txt, file, cmp, y, x));
-   if(a[0] == '$' && a[1] == '{')
-   {  for(k = 2; a[k] && a[k] != '}'; k++);
-      var = MALLOC((k-1) * sizeof(char));
-      for(i = 2; i < k; i++) var[i-2] = a[i];
-      var[k-2] = '\0';
-      if(a[k]) k++;
-      if(!a[k]) return(!e_p_konv_mess(var, b, txt, file, cmp, y, x));
-      n = a[k] == '\\' ? k : k+1;
+ if (c > b)
+  return(0);
+ if (a[0] == '*' && !a[1])
+  return(2);
+ if (!a[0] && !b[0])
+  return(2);
+ if (!a[0] || !b[0])
+  return(0);
+ if (a[0] == '*' && (a[1] == '*' || a[1] == '$'))
+  return(e_p_comp_mess(++a, b, c, txt, file, cmp, y, x));
+ if (a[0] == '$' && a[1] == '{')
+ {
+  for (k = 2; a[k] && a[k] != '}'; k++);
+  var = MALLOC((k-1) * sizeof(char));
+  for (i = 2; i < k; i++)
+   var[i-2] = a[i];
+  var[k-2] = '\0';
+  if (a[k])
+   k++;
+  if (!a[k])
+   return(!e_p_konv_mess(var, b, txt, file, cmp, y, x));
+  n = a[k] == '\\' ? k : k+1;
+ }
+ else if (a[0] == '*'&& a[1] != '\\')
+ {
+  k = 1;
+  n = 2;
+ }
+ else
+  n = 1;
+ for(; bsl || (a[n] && a[n] != '*' && a[n] != '?' && a[n] != '[' &&
+   (a[n] != '$' || a[n+1] != '{' )); n++)
+  bsl = a[n] == '\\' ? !bsl : 0;
+ if (a[0] == '*' || a[0] == '$')
+ {
+  if (a[k] == '?')
+  {
+   cp = MALLOC((strlen(a)+1)*sizeof(char));
+   for (i = 0; i < k && (cp[i] = a[i]); i++);
+   for (i++; (cp[i-1] = a[i]) != '\0'; i++);
+   FREE(var);
+   n = e_p_comp_mess(cp, ++b, ++c, txt, file, cmp, y, x);
+   FREE(cp);
+   return(n);
+  }
+  if (a[k] == '[')
+  {
+   for (i = 0; b[i] &&
+     !(n = e_p_comp_mess(a+k, b+i, c+i, txt, file, cmp, y, x)); i++)
+    ;
+   if (!b[i])
+    return(0);
+   if (a[0] == '$')
+   {
+    str = MALLOC((i+1)*sizeof(char));
+    for (k = 0; k < i; k++)
+     str[k] = b[k];
+    str[i] = '\0';
+    e_p_konv_mess(var, str, txt, file, cmp, y, x);
+    FREE(var);
+    FREE(str);
    }
-   else if(a[0] == '*'&& a[1] != '\\') {  k = 1; n = 2;  }
-   else n = 1;
-   for(; bsl || (a[n] && a[n] != '*' && a[n] != '?' && a[n] != '['
-			&& (a[n] != '$' || a[n+1] != '{' )); n++)
-   bsl = a[n] == '\\' ? !bsl : 0;
-   if(a[0] == '*' || a[0] == '$')
-   {  if(a[k] == '?')
-      {  cp = MALLOC((strlen(a)+1)*sizeof(char));
-	 for(i = 0; i < k && (cp[i] = a[i]); i++);
-	 for(i++; (cp[i-1] = a[i]) != '\0'; i++);
-	 FREE(var);
-	 n = e_p_comp_mess(cp, ++b, ++c, txt, file, cmp, y, x);
-	 FREE(cp);
-	 return(n);
-      }
-      if(a[k] == '[')
-      {  for(i = 0; b[i] &&
-		!(n = e_p_comp_mess(a+k, b+i, c+i, txt, file, cmp, y, x)); i++);
-	 if(!b[i]) return(0);
-	 if(a[0] == '$')
-	 {  str = MALLOC((i+1)*sizeof(char));
-	    for(k = 0; k < i; k++) str[k] = b[k];
-	    str[i] = '\0';
-	    e_p_konv_mess(var, str, txt, file, cmp, y, x);
-	    FREE(var);
-	    FREE(str);
-	 }
-	 return(n);
-      }
-      n -= k;
-      ctmp = MALLOC(n+1);
-      for(i = 0; i < n; i++) ctmp[i] = a[i+k];
-      ctmp[n] = '\0';
-      cp = strstr(b, ctmp);
-      FREE(ctmp);
-      if(cp == NULL) return(0);
-      if(a[0] == '$')
-      {  for(i = 0; c + i < cp; i++);
-	 str = MALLOC((i+1)*sizeof(char));
-	 for(i = 0; c + i < cp; i++) str[i] = c[i];
-	 str[i] = '\0';
-	 i = e_p_konv_mess(var, str, txt, file, cmp, y, x);
-	 FREE(var);  
-	 FREE(str);
-	 if(i) return(0);
-      }
-      if(!a[k+n] && !cp[n]) return(2);
-      if(!a[k+n]) return(e_p_comp_mess(a, cp+1, cp+1, txt, file, cmp, y, x));
-      if((i = e_p_comp_mess(a+k+n, cp+n, cp+n, txt, file, cmp, y, x))) return(i);
-      if(file[0] && *y > -1) return(0);
-      return(e_p_comp_mess(a, cp+1, a[0] == '$' ? c : cp+1, 
-					txt, file, cmp, y, x));
-   }
-   else if(a[0] == '?') {  n--;  a++;  b++;  }
-   else if(a[0] == '[')
-   {  if(a[1] == '!')
-      {  for(k = 2; a[k] && (a[k] != ']' || k == 2) && a[k] != b[0]; k++)
-	 if(a[k+1] == '-' && b[0] >= a[k] && b[0] <= a[k+2]) return(-b[0]);
-	 if(a[k] != ']') return(-b[0]);
-	 n-=(k+1);  a+=(k+1);  b++;
-      }
-      else
-      {  for(k = 1; a[k] && (a[k] != ']' || k == 1) && a[k] != b[0]; k++)
-	 if(a[k+1] == '-' && b[0] >= a[k] && b[0] <= a[k+2]) break;
-	 if(a[k] == ']' || a[k] == '\0') return(0);
-	 for(; a[k] && (a[k] != ']'); k++);
-	 n-=(k+1);  a+=(k+1);  b++;
-      }
-   }
-   if(n <= 0) return(e_p_comp_mess(a, b, c, txt, file, cmp, y, x));
-   if((k = strncmp(a, b, n)) != 0) return(0);
-   return(e_p_comp_mess(a+n, b+n, c+n, txt, file, cmp, y, x));
+   return(n);
+  }
+  n -= k;
+  ctmp = MALLOC(n+1);
+  for (i = 0; i < n; i++)
+   ctmp[i] = a[i+k];
+  ctmp[n] = '\0';
+  cp = strstr(b, ctmp);
+  FREE(ctmp);
+  if (cp == NULL)
+   return(0);
+  if (a[0] == '$')
+  {
+   for (i = 0; c + i < cp; i++);
+   str = MALLOC((i+1)*sizeof(char));
+   for (i = 0; c + i < cp; i++)
+    str[i] = c[i];
+   str[i] = '\0';
+   i = e_p_konv_mess(var, str, txt, file, cmp, y, x);
+   FREE(var);  
+   FREE(str);
+   if (i)
+    return(0);
+  }
+  if (!a[k+n] && !cp[n])
+   return(2);
+  if (!a[k+n])
+   return(e_p_comp_mess(a, cp+1, cp+1, txt, file, cmp, y, x));
+  if ((i = e_p_comp_mess(a+k+n, cp+n, cp+n, txt, file, cmp, y, x)))
+   return(i);
+  if (file[0] && *y > -1)
+   return(0);
+  return(e_p_comp_mess(a, cp+1, a[0] == '$' ? c : cp+1, txt, file, cmp, y, x));
+ }
+ else if (a[0] == '?')
+ {
+  n--;
+  a++;
+  b++;
+ }
+ else if (a[0] == '[')
+ {
+  if (a[1] == '!')
+  {
+   for (k = 2; a[k] && (a[k] != ']' || k == 2) && a[k] != b[0]; k++)
+    if (a[k+1] == '-' && b[0] >= a[k] && b[0] <= a[k+2])
+     return(-b[0]);
+   if (a[k] != ']')
+    return(-b[0]);
+   n-=(k+1);
+   a+=(k+1);
+   b++;
+  }
+  else
+  {
+   for (k = 1; a[k] && (a[k] != ']' || k == 1) && a[k] != b[0]; k++)
+    if (a[k+1] == '-' && b[0] >= a[k] && b[0] <= a[k+2])
+     break;
+   if (a[k] == ']' || a[k] == '\0')
+    return(0);
+   for(; a[k] && (a[k] != ']'); k++);
+   n-=(k+1);
+   a+=(k+1);
+   b++;
+  }
+ }
+ if (n <= 0)
+  return(e_p_comp_mess(a, b, c, txt, file, cmp, y, x));
+ if ((k = strncmp(a, b, n)) != 0)
+  return(0);
+ return(e_p_comp_mess(a+n, b+n, c+n, txt, file, cmp, y, x));
 }
 
 int e_p_cmp_mess(char *srch, BUFFER *b, int *ii, int *kk, int ret)
 {
-   char *cp, cmp[128], file[128], search[80], tmp[4][128], **wtxt = NULL;
-   int j, l, m, n, iy, i = *ii, k = *kk, x = 0, y = -1, wnum = 0, *wn = NULL;
+ char *cp, cmp[128], file[128], search[80], tmp[4][128], **wtxt = NULL;
+ int j, l, m, n, iy, iorig, i = *ii, k = *kk, x = 0, y = -1, wnum = 0;
+ int *wn = NULL;
 
-   cmp[0] = search[0] = file[0] = '\0';
-   wtxt = MALLOC(1);
-   wn = MALLOC(1);
-   for(j = 0, n = 0; n < 4 && srch[j]; n++)
-   {  for(l = 0; (tmp[n][l] = srch[j]); j++, l++)
-      {  if(j > 1 && srch[j] == '?' && srch[j-1] == '{' && srch[j-2] == '$')
-	 {  wnum++;
-	    wn = REALLOC(wn, wnum * sizeof(int));
-	    wtxt = REALLOC(wtxt, wnum * sizeof(char *));
-	    if(srch[j+1] == '*') wn[wnum-1] = -1;
-	    else wn[wnum-1] = atoi(srch+j+1);
-	    for(j++; srch[j] && srch[j] != ':'; j++);
-	    if(!srch[j]) {  wnum--;  break;  }
-	    for(m = 0; srch[j+m] && srch[j+m] != '}'; m++);
-	    wtxt[wnum-1] = MALLOC((m+1) * sizeof(char));
-	    for(m = 0, j++;
-		(wtxt[wnum-1][m] = srch[j]) && srch[j] != '}'; j++, m++);
-	    wtxt[wnum-1][m] = '\0';
-	    l -= 3;
-	 }
-	 else if(srch[j] == '\r' || srch[j] == '\n')
-	 {  if(srch[j+1] == '\r' || srch[j+1] == '\n')
-	    {  tmp[n][l] = '\n';  tmp[n][l+1] = '\0';  j++;  }
-	    else tmp[n][l] = '\0';
-	    j++;  break;
-	 }
-      }
+ cmp[0] = search[0] = file[0] = '\0';
+ wtxt = MALLOC(1);
+ wn = MALLOC(1);
+ for (j = 0, n = 0; n < 4 && srch[j]; n++)
+ {
+  for (l = 0; (tmp[n][l] = srch[j]); j++, l++)
+  {
+   if (j > 1 && srch[j] == '?' && srch[j-1] == '{' && srch[j-2] == '$')
+   {
+    wnum++;
+    wn = REALLOC(wn, wnum * sizeof(int));
+    wtxt = REALLOC(wtxt, wnum * sizeof(char *));
+    if (srch[j+1] == '*')
+     wn[wnum-1] = -1;
+    else
+     wn[wnum-1] = atoi(srch+j+1);
+    for (j++; srch[j] && srch[j] != ':'; j++);
+    if (!srch[j])
+    {
+     wnum--;
+     break;
+    }
+    for (m = 0; srch[j+m] && srch[j+m] != '}'; m++);
+    wtxt[wnum-1] = MALLOC((m+1) * sizeof(char));
+    for (m = 0, j++; (wtxt[wnum-1][m] = srch[j]) && srch[j] != '}'; j++, m++);
+    wtxt[wnum-1][m] = '\0';
+    l -= 3;
    }
-   e_p_comp_mess(tmp[0], b->bf[i].s, b->bf[i].s, search, file, cmp, &y, &x);
+   else if (srch[j] == '\r' || srch[j] == '\n')
+   {
+    if (srch[j+1] == '\r' || srch[j+1] == '\n')
+    {
+     tmp[n][l] = '\n';
+     tmp[n][l+1] = '\0';
+     j++;
+    }
+    else
+     tmp[n][l] = '\0';
+    j++;
+    break;
+   }
+  }
+ }
+ e_p_comp_mess(tmp[0], b->bf[i].s, b->bf[i].s, search, file, cmp, &y, &x);
+ iy = i;
+ iorig = i;
+ do
+ {
+  if (n > 1 && file[0] && i < b->mxlines-1)
+  {
+   y = -1;
+   while (b->bf[i].s[b->bf[i].len-1] == '\\')
+    i++;
+   i++;
+   e_p_comp_mess(tmp[1], b->bf[i].s, b->bf[i].s, search, file, cmp, &y, &x);
    iy = i;
-   do
-   {  if(n > 1 && file[0] && i < b->mxlines-1)
-      {  y = -1;
-	 while(b->bf[i].s[b->bf[i].len-1] == '\\') i++;
-	 i++;
-	 e_p_comp_mess(tmp[1], b->bf[i].s, b->bf[i].s, search, file, cmp, &y, &x);
-	 iy = i;
-      }
-      do
-      {  if(n > 2 && file[0] && y >= 0 && i < b->mxlines-1)
-	 {  while(b->bf[i].s[b->bf[i].len-1] == '\\') i++;
-	    i++;
-	    l = e_p_comp_mess(tmp[2], b->bf[i].s, b->bf[i].s, search, file, cmp, &y, &x);
-	    if(!l && n > 3)
-	    l = e_p_comp_mess(tmp[3], b->bf[i].s, b->bf[i].s, search, file, cmp, &y, &x);
-	 }
-	 else l = 1;
-	 if(file[0] && y >= 0 && l != 0)
-	 {  err_li[k].file = MALLOC((strlen(file)+1)*sizeof(char));
-	    strcpy(err_li[k].file, file);
-	    err_li[k].line = y;
-	    if(search[0] == 'P')
-	    {  cp = strstr(b->bf[iy].s, cmp);
-	       if(!cp) x = 0;
-	       else
-	       {  for(m = 0; b->bf[iy].s + m < (unsigned char *)cp; m++);
-		  x -= m;
-	       }
-	       err_li[k].srch = MALLOC((strlen(cmp)+2)*sizeof(char));
-	       err_li[k].srch[0] = 'P';
-	       strcpy(err_li[k].srch+1, cmp);
-	    }
-	    else if(search[0])
-	    {  err_li[k].srch = MALLOC((strlen(search)+1)*sizeof(char));
-	       strcpy(err_li[k].srch, search);
-	    }
-	    else err_li[k].srch = NULL;
-	    err_li[k].x = x;
-	    err_li[k].y = i;
-	    err_li[k].text = MALLOC(strlen((char *)b->bf[i].s) + 1);
-	    strcpy(err_li[k].text, (char *)b->bf[i].s);
-	    err_li[k].text[b->bf[i].len] = '\0';
-	    k++;
-	    err_num++;
-	    if(!ret)
-	    {  for(ret = -1, m = 0; ret && m < wnum; m++)
-	       {  if(wn[m] == -1 && !(b->cn->edopt & ED_MESSAGES_STOP_AT)
-			    && strstr(b->bf[i].s, wtxt[m])) ret = 0;
-		  else if(wn[m] > -1 && !(b->cn->edopt & ED_MESSAGES_STOP_AT)
-			&& !strncmp(b->bf[i].s+wn[m], wtxt[m],
-					strlen(wtxt[m]))) ret = 0;
-	       }
-	    }
-	    if(!ret && wnum <= 0) ret = -1;
-            while(b->bf[i].s[b->bf[i].len-1] == '\\') i++;
-	 }
-      } while(n > 2 && file[0] && y >= 0 && l != 0 && i < b->mxlines-1);
-      if(n > 2 && file[0] && y >= 0 && l == 0) i--;
-   } while(n > 1 && file[0] && y >= 0 && i < b->mxlines-1);
-   if(n > 1 && file[0] && y < 0) i--;
-   *ii = i;
-   *kk = k;
-   for(m = 0; m < wnum; m++) FREE(wtxt[m]);
-   FREE(wn);
-   FREE(wtxt);
-   return(ret);
+  }
+  do
+  {
+   if (n > 2 && file[0] && y >= 0 && i < b->mxlines-1)
+   {
+    while (b->bf[i].s[b->bf[i].len-1] == '\\')
+     i++;
+    i++;
+    l = e_p_comp_mess(tmp[2], b->bf[i].s, b->bf[i].s, search, file, cmp, &y, &x);
+    if (!l && n > 3)
+     l = e_p_comp_mess(tmp[3], b->bf[i].s, b->bf[i].s, search, file, cmp, &y, &x);
+   }
+   else
+    l = 1;
+   if (file[0] && y >= 0 && l != 0)
+   {
+    err_li[k].file = MALLOC((strlen(file)+1)*sizeof(char));
+    strcpy(err_li[k].file, file);
+    err_li[k].line = y;
+    if (search[0] == 'P')
+    {
+     cp = strstr(b->bf[iy].s, cmp);
+     if (!cp)
+      x = 0;
+     else
+     {
+      for (m = 0; b->bf[iy].s + m < (unsigned char *)cp; m++);
+      x -= m;
+     }
+     err_li[k].srch = MALLOC((strlen(cmp)+2)*sizeof(char));
+     err_li[k].srch[0] = 'P';
+     strcpy(err_li[k].srch+1, cmp);
+    }
+    else if (search[0])
+    {
+     err_li[k].srch = MALLOC((strlen(search)+1)*sizeof(char));
+     strcpy(err_li[k].srch, search);
+    }
+    else
+     err_li[k].srch = NULL;
+    err_li[k].x = x;
+    err_li[k].y = iorig;
+    err_li[k].text = MALLOC(strlen((char *)b->bf[i].s) + 1);
+    strcpy(err_li[k].text, (char *)b->bf[i].s);
+    err_li[k].text[b->bf[i].len] = '\0';
+    k++;
+    err_num++;
+    if (!ret)
+    {
+     for (ret = -1, m = 0; ret && m < wnum; m++)
+     {
+      if (wn[m] == -1 && !(b->cn->edopt & ED_MESSAGES_STOP_AT) &&
+        strstr(b->bf[i].s, wtxt[m]))
+       ret = 0;
+      else if (wn[m] > -1 && !(b->cn->edopt & ED_MESSAGES_STOP_AT) &&
+        !strncmp(b->bf[i].s+wn[m], wtxt[m], strlen(wtxt[m])))
+       ret = 0;
+     }
+    }
+    if (!ret && wnum <= 0)
+     ret = -1;
+    while (b->bf[i].s[b->bf[i].len-1] == '\\')
+     i++;
+   }
+  } while (n > 2 && file[0] && y >= 0 && l != 0 && i < b->mxlines-1);
+  if (n > 2 && file[0] && y >= 0 && l == 0)
+   i--;
+ } while (n > 1 && file[0] && y >= 0 && i < b->mxlines-1);
+ if (n > 1 && file[0] && y < 0)
+  i--;
+ *ii = i;
+ *kk = k;
+ for (m = 0; m < wnum; m++)
+  FREE(wtxt[m]);
+ FREE(wn);
+ FREE(wtxt);
+ return(ret);
 }
 
 #endif
