@@ -187,92 +187,98 @@ int e_pr_filetype(FENSTER *f)
 /*   open section of screen and save background  */
 PIC *e_open_view(int xa, int ya, int xe, int ye, int col, int sw)
 {
-   PIC *pic = MALLOC(sizeof(PIC));
-   int i, j;
-   if (pic == NULL) return(NULL);
-   pic->a.x = xa;
-   pic->a.y = ya;
+ PIC *pic = MALLOC(sizeof(PIC));
+ int i, j;
+
+ if (pic == NULL) return(NULL);
+ pic->a.x = xa;
+ pic->a.y = ya;
 #ifndef NEWSTYLE
-   if(!WpeIsXwin())
-   {  pic->e.x = xe;
-      pic->e.y = ye;
-   }
-   else
-   {  pic->e.x = xe < MAXSCOL-2 ? xe + 2 : xe < MAXSCOL-1 ? xe + 1 : xe;
-      pic->e.y = ye < MAXSLNS-2 ? ye + 1 : ye;
-   }
+ if(!WpeIsXwin())
+ {
+  pic->e.x = xe;
+  pic->e.y = ye;
+ }
+ else
+ {
+  pic->e.x = xe < MAXSCOL-2 ? xe + 2 : xe < MAXSCOL-1 ? xe + 1 : xe;
+  pic->e.y = ye < MAXSLNS-2 ? ye + 1 : ye;
+ }
 #else
-   pic->e.x = xe;
-   pic->e.y = ye;
+ pic->e.x = xe;
+ pic->e.y = ye;
 #endif
-   if (sw!=0)
+ if (sw!=0)
+ {
 #if defined(NEWSTYLE) && !defined(NO_XWINDOWS)
-   {  pic->p = MALLOC( (pic->e.x - pic->a.x + 1) * 3
-					* (pic->e.y - pic->a.y + 1) );
+  pic->p = MALLOC((pic->e.x - pic->a.x + 1) * 3 * (pic->e.y - pic->a.y + 1));
 #else
-   {  pic->p = MALLOC( (pic->e.x - pic->a.x + 1) * 2
-					* (pic->e.y - pic->a.y + 1) );
+  pic->p = MALLOC((pic->e.x - pic->a.x + 1) * 2 * (pic->e.y - pic->a.y + 1));
 #endif
-      if (pic->p == NULL) {  FREE(pic);  return(NULL);  }
-      for (j = pic->a.y; j <= pic->e.y; ++j)
-      for (i = 2*pic->a.x; i <= 2*pic->e.x+1; ++i)
-          *( pic->p + (j-pic->a.y)*2*(pic->e.x-pic->a.x+1)
-				 + (i-2*pic->a.x) ) = e_gt_byte(i, j);
+  if (pic->p == NULL) {  FREE(pic);  return(NULL);  }
+  for (j = pic->a.y; j <= pic->e.y; ++j)
+   for (i = 2*pic->a.x; i <= 2*pic->e.x+1; ++i)
+    *( pic->p + (j-pic->a.y)*2*(pic->e.x-pic->a.x+1) + (i-2*pic->a.x) ) = e_gt_byte(i, j);
 #if defined(NEWSTYLE) && !defined(NO_XWINDOWS)
-      e_get_pic_xrect(xa, ya, xe, ye, pic);
+  e_get_pic_xrect(xa, ya, xe, ye, pic);
 #endif
-   }
-   else pic->p = (char *)0;
-   if(sw < 2)
-   {  for (j = ya; j <= ye; ++j)
-      for (i = xa; i <= xe; ++i)
-      e_pr_char(i, j, ' ', col);
-   }
+ }
+ else pic->p = (char *)0;
+ if (sw < 2)
+ {
+  for (j = ya; j <= ye; ++j)
+   for (i = xa; i <= xe; ++i)
+    e_pr_char(i, j, ' ', col);
+ }
 #ifndef NO_XWINDOWS
-   if (WpeIsXwin()) (*e_u_setlastpic)(pic);
+ if (WpeIsXwin()) (*e_u_setlastpic)(pic);
 #endif
 #ifndef NEWSTYLE
-   if (WpeIsXwin())
-   {  if(sw != 0)
-      {  if(xe < MAXSCOL-1) for(i = ya+1; i <= ye+1 && i < MAXSLNS-1; i++)
-	 e_pt_col(xe+1, i, SHDCOL);
-	 if(xe < MAXSCOL-2) for(i = ya+1; i <= ye+1 && i < MAXSLNS-1; i++)
-	 e_pt_col(xe+2, i, SHDCOL);
-	 if(ye < MAXSLNS-2) for(i = xa+2; i <= xe; i++) e_pt_col(i, ye+1, SHDCOL);
-      }
-   }
+ if (WpeIsXwin())
+ {
+  if (sw != 0)
+  {
+   if (xe < MAXSCOL-1) for(i = ya+1; i <= ye+1 && i < MAXSLNS-1; i++)
+    e_pt_col(xe+1, i, SHDCOL);
+   if (xe < MAXSCOL-2) for(i = ya+1; i <= ye+1 && i < MAXSLNS-1; i++)
+    e_pt_col(xe+2, i, SHDCOL);
+   if (ye < MAXSLNS-2) for(i = xa+2; i <= xe; i++) e_pt_col(i, ye+1, SHDCOL);
+  }
+ }
 #endif
-   return(pic);
+ return(pic);
 }
 
 /*   close screen section - refresh background  */
 int e_close_view(PIC *pic, int sw)
 {
-   int i, j;
+ int i, j;
 #ifndef NO_XWINDOWS
-   if (WpeIsXwin()) (*e_u_setlastpic)(NULL);
+ if (WpeIsXwin()) (*e_u_setlastpic)(NULL);
 #endif
-   if(pic == NULL) return(-1);
-   if (sw!=0 && pic->p != NULL)
-   {  for (j = pic->a.y; j <= pic->e.y; ++j)
-      for (i = 2*pic->a.x; i <= 2*pic->e.x+1; ++i)
-      e_pt_byte(i, j, *( pic->p + (j-pic->a.y)*2*(pic->e.x-pic->a.x+1)
-                                                        + (i-2*pic->a.x) ));
+ if (pic == NULL) return(-1);
+ if (sw != 0 && pic->p != NULL)
+ {
+  for (j = pic->a.y; j <= pic->e.y; ++j)
+   for (i = 2*pic->a.x; i <= 2*pic->e.x+1; ++i)
+    e_pt_byte(i, j, *(pic->p + (j-pic->a.y)*2*(pic->e.x-pic->a.x+1) + (i-2*pic->a.x)));
 #if defined(NEWSTYLE) && !defined(NO_XWINDOWS)
-      e_put_pic_xrect(pic);
+  e_put_pic_xrect(pic);
 #endif
-   }
-   else if(sw!=0)
-   {  for (j = pic->a.y; j <= pic->e.y; ++j)
-      for (i = pic->a.x; i <= pic->e.x; ++i)
-      e_pr_char(i, j, ' ', 0);
-   }
-   if(sw < 2)
-   {  if(pic->p != NULL) FREE(pic->p);
-      FREE(pic);
-   }
-   e_refresh();
-   return(sw);
+ }
+ else if (sw != 0)
+ {
+  for (j = pic->a.y; j <= pic->e.y; ++j)
+   for (i = pic->a.x; i <= pic->e.x; ++i)
+    e_pr_char(i, j, ' ', 0);
+ }
+ if (sw < 2)
+ {
+  if (pic->p != NULL) FREE(pic->p);
+  FREE(pic);
+ }
+ e_refresh();
+ return(sw);
 }
 
 /*    Frame for edit window   */
